"use client"
import * as Icon from "react-feather";
import { useForm } from "react-hook-form";
import { useState } from "react";
import Swal from "sweetalert2";
import {ApiConfig, handleApiRequest} from "@/app/services/apiConfig";
import {useTranslations} from "next-intl";

export const ContactUsForm = () => {
    const t = useTranslations('contactUs');
    const {
        register,
        handleSubmit,
        formState: { errors },
        reset,
    } = useForm();
    const [loading, setLoading] = useState(false);

    const onSubmit = async (data) => {
        setLoading(true);

        try {
            const body = {
                name: data.name,
                email: data.email,
                subject: data.subject,
                message: data.comments,
            }
            const response = await handleApiRequest(
                ApiConfig.endpoints.submitContactUs,
                "contact-us",
                "POST",
                JSON.stringify(body),
                false,
                "client"
            );
            console.log(response);

            Swal.fire({
                icon: "success",
                title: "Success",
                text: "Your message has been sent successfully!",
            });

            reset();
        } catch (error) {
            console.error(error);
            Swal.fire({
                icon: "error",
                title: "Submission Failed",
                text: "There was an error sending your message. Please try again.",
            });
        } finally {
            setLoading(false);
        }
    };

    return (
        <form onSubmit={handleSubmit(onSubmit)}>
            <div className="grid lg:grid-cols-12 lg:gap-6">
                {/* Name Field */}
                <div className="lg:col-span-6 mb-5">
                    <div className="text-start">
                        <label htmlFor="name" className="font-semibold">{t("yourName")}</label>
                        <div className="form-icon relative mt-2">
                            <Icon.User className="size-4 absolute top-3 start-4" />
                            <input
                                name="name"
                                id="name"
                                type="text"
                                {...register("name", { required: "Name is required" })}
                                className={`form-input ps-11 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.name ? "border-red-500 focus:border-red-500" : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("name")}
                            />
                        </div>
                        {errors.name && <span className="text-red-600">{errors.name.message}</span>}
                    </div>
                </div>

                {/* Email Field */}
                <div className="lg:col-span-6 mb-5">
                    <div className="text-start">
                        <label htmlFor="email" className="font-semibold">{t("yourEmail")}</label>
                        <div className="form-icon relative mt-2">
                            <Icon.Mail className="size-4 absolute top-3 start-4" />
                            <input
                                name="email"
                                id="email"
                                type="email"
                                {...register("email", {
                                    required: "Email is required",
                                    pattern: {
                                        value: /^\S+@\S+$/i,
                                        message: "Invalid email address",
                                    },
                                })}
                                className={`form-input ps-11 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.email ? "border-red-500 focus:border-red-500" : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("email")}
                            />
                        </div>
                        {errors.email && <span className="text-red-600">{errors.email.message}</span>}
                    </div>
                </div>
            </div>

            <div className="grid grid-cols-1">
                {/* Subject Field */}
                <div className="mb-5">
                    <div className="text-start">
                        <label htmlFor="subject" className="font-semibold">{t("yourQuestion")}</label>
                        <div className="form-icon relative mt-2">
                            <Icon.Book className="size-4 absolute top-3 start-4" />
                            <input
                                name="subject"
                                id="subject"
                                {...register("subject", { required: "Subject is required" })}
                                className={`form-input ps-11 w-full py-2 px-3 h-10 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.subject ? "border-red-500 focus:border-red-500" : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("subject")}
                            />
                        </div>
                        {errors.subject && <span className="text-red-600">{errors.subject.message}</span>}
                    </div>
                </div>

                {/* Comments Field */}
                <div className="mb-5">
                    <div className="text-start">
                        <label htmlFor="comments" className="font-semibold">{t("yourComment")}</label>
                        <div className="form-icon relative mt-2">
                            <Icon.MessageCircle className="size-4 absolute top-3 start-4" />
                            <textarea
                                name="comments"
                                id="comments"
                                {...register("comments", { required: "Comments are required" })}
                                className={`form-input ps-11 w-full py-2 px-3 h-28 bg-transparent dark:bg-slate-900 dark:text-slate-200 rounded outline-none border ${
                                    errors.comments ? "border-red-500 focus:border-red-500" : "border-gray-200 focus:border-main dark:border-gray-800 dark:focus:border-main"
                                } focus:ring-0`}
                                placeholder={t("message")}
                            ></textarea>
                        </div>
                        {errors.comments && <span className="text-red-600">{errors.comments.message}</span>}
                    </div>
                </div>
            </div>

            <button
                type="submit"
                id="submit"
                name="send"
                disabled={loading}
                className={`py-2 px-5 font-semibold tracking-wide border align-middle duration-500 text-base text-center bg-main hover:bg-main-hover border-main hover:border-main-hover text-white rounded-md justify-center flex items-center w-full ${
                    loading ? "cursor-not-allowed opacity-50" : ""
                }`}
            >
                {loading ? t("sending...") : t("sendMessage")}
            </button>
        </form>
    );
};
